/**
 * ip地址转换为整数
 */
const is: any = (window as any).is;
export const ipv4ToNumber = (ip: string): number => {
    let num = 0;
    if (ip === '') {
        return num;
    }
    const aNum = ip.split('.');
    if (aNum.length !== 4) {
        return num;
    }
    num += parseInt(aNum[0]) << 24;
    num += parseInt(aNum[1]) << 16;
    num += parseInt(aNum[2]) << 8;
    num += parseInt(aNum[3]) << 0;
    // 这个很关键，不然可能会出现负数的情况
    num = num >>> 0;
    return num;
};

/**
 * 整数转换为ip地址字符串
 * @param: number
 */
export const numberToIpv4 = (number: number): string => {
    let ip = '';
    if (number <= 0) {
        return ip;
    }
    const ip3 = (number << 0) >>> 24;
    const ip2 = (number << 8) >>> 24;
    const ip1 = (number << 16) >>> 24;
    const ip0 = (number << 24) >>> 24;
    ip += ip3 + '.' + ip2 + '.' + ip1 + '.' + ip0;
    return ip;
};

export const isIPv4 = (ipLikeString: string): boolean => {
    if (is.ipv4(ipLikeString)) {
        return true;
    }
    // 10.1.1.1-10.2.1.1 模式可以通过
    const tempArr = ipLikeString.split('-');
    if (tempArr.length === 2) {
        // 10.1.1.1- 和 -10.1.1.1 不通过
        if (tempArr[0] === '' || tempArr[1] === '') {
            return false;
        }
        if (is.ipv4(tempArr[0]) && is.ipv4(tempArr[1])) {
            if (ipv4ToNumber(tempArr[1]) > ipv4ToNumber(tempArr[0])) {
                return true;
            }
        }
    }
    const arr = ipLikeString.split('.');
    if (arr.length !== 4) {
        return false;
    }
    for (let i = 0; i < arr.length; i++) {
        if (arr[i].indexOf('-') >= 0) {
            // 10.1.1.1-10 模式可以通过
            const t = arr[i].split('-');
            if (t.length > 2) {
                return false;
            }

            // 让 192.168.1-10.* 混合模式也可以通过
            if (Number(t[1]) > Number(t[0])) {
                arr[i] = t[1];
            }
        } else if (arr[i].indexOf('/') >= 0) {
            // 网段 192.168.1.1/18 模式可以通过
            const t = arr[i].split('/');
            if (t.length > 2) {
                return false;
            }
            if (Number(t[1]) >= 0 && Number(t[1]) <= 32) {
                arr[i] = t[0];
            }
        } else if (arr[i] === '*') {
            // 10.1.1.* 和 10.*.*.* 模式可以通过
            if (arr.slice(i, 4).join('') !== '*'.repeat(4 - i)) {
                return false;
            }
        }
    }
    const res = arr.join('.');
    if (res.endsWith('.*') || res.endsWith('.*.*') || res.endsWith('.*.*.*')) {
        const temp = res.replace(/\*/g, '1');
        if (is.ipv4(temp)) {
            return true;
        }
    }
    return is.ipv4(res);
};
export const isIPv6 = (ipLikeString: string) => {
    // return is.ipv6(ipLikeString);
    if (is.ipv6(ipLikeString)) {
        return true;
    }
    for (let item of ipLikeString.split('-')) {
        if (!is.ipv6(item)) {
            return false;
        }
    }
    return true;
};
