import { Component, OnInit, ViewChild, Input, EventEmitter, Output, forwardRef } from '@angular/core';
import { NzTreeComponent, NzTreeNodeOptions, NzFormatEmitEvent } from 'ng-zorro-antd';
import { HttpService } from '../../../core';
import { ControlValueAccessor, NG_VALUE_ACCESSOR } from '@angular/forms';

@Component({
    selector: 'app-asset-tree-group',
    templateUrl: './asset-tree-group.component.html',
    styleUrls: ['./asset-tree-group.component.styl'],
    providers: [{
        provide: NG_VALUE_ACCESSOR, // 为form control提供ControlValueAccessor，所以我们的组件要实现ControlValueAccessor接口。
        // tslint:disable-next-line: max-line-length
        useExisting: forwardRef(() => AssetTreeGroupComponent), // 在依赖注入中，每个组件都需要有个与其关联的token，可是在provider注册的时候，我们的组件还没有初始化。所以需要使用forwardRef来告知provider构造器这些，使其可以等组件初始化。
        multi: true, // 避免出现多个provider
    }],
})
export class AssetTreeGroupComponent implements OnInit, ControlValueAccessor {

    // viewId: any = 1;   // 默认的视图id为1
    private _value: any;
    private onTouchedCallback: () => {}; // 实现都会在组件初始化时由Angular自己来提供
    private onChangeCallback: (_: any) => {}; // 用于接收registerOnChange()方法里传递回来的方法，然后通过这个方法就能通知到外部组件数据更新。

    @Output() assetValueChange = new EventEmitter();
    set value(inputValue) {
        if (inputValue !== this._value) {
            this._value = inputValue;
            this.onChangeCallback(inputValue); // 通知外部更新
            this.assetValueChange.emit(this._value);
        }
    }
    @Input() get value() {
        return this._value;
    }
    nodes: NzTreeNodeOptions[] = [];

    viewValue: any = {};
    viewList: any = [];

    unvisible = true;
    showClose = false;
    @ViewChild('nzTreeComponent') nzTreeComponent: NzTreeComponent;

    // 资产列表
    childAssets = {
        p_name: '',
        loading: false,
        data: undefined,
        total: 0,       // 总数
        page_index: 1,  // 当前页
        page_size: 10,  // 当前页大小
        total_page: 0   // 总分页数
    };
    curGroupNodeKey: any;  // 当前选择的资产组的key值
    keywords: string;   // 关键字搜索资产
    constructor(private httpService: HttpService) { }

    writeValue(value: any): void {// 初始化,初始化的时候调用 writeValue() 方法，将会使用表单模型中对应ngModel的初始值作为参数（也就是ngModel里的值）。
        if (value !== this._value) {
            this._value = value;
        }
    }

    registerOnChange(fn: any): void {// 通知外部，组件已经发生变化，将组件里更新的数据传递出去。初始化后，执行该方法，保存控件接收到onChangeCallback事件后，调用的函数.
        this.onChangeCallback = fn;
    }

    registerOnTouched(fn: any): void {// 当控件接收到 touched 事件后，调用的函数。
        this.onTouchedCallback = fn;
    }

    hoverIn(ev) {
        this.showClose = true;
        ev.stopPropagation();
    }

    hoverOut(ev) {
        if (ev && (ev.toElement.tagName === 'svg' || ev.toElement.className === 'ng-star-inserted' || ev.toElement.tagName === 'path')) {
            this.showClose = true;
        } else {
            this.showClose = false;
        }
        // console.log(ev.toElement);
        // console.log(ev.toElement.tagName);
        // console.log('outother');
        ev.stopPropagation();
    }

    async ngOnInit() {
        await this.getViewList();
        this.getAssets();
        // TODO 接口实现
        // this.nodes = [
        //     {
        //         title: '全部',
        //         key: '全部',
        //         children: [
        //             {
        //                 title: '资产组1名称',
        //                 key: '资产组1 id',
        //                 children: [
        //                     { title: '资产1名称', key: '资产1 id', isLeaf: true },
        //                     { title: '资产2名称', key: '资产2 id', isLeaf: true },
        //                 ]
        //             },
        //             {
        //                 title: '资产组2名称',
        //                 key: '资产组2 id',
        //                 children: [
        //                     { title: '资产3名称', key: '资产3 id', isLeaf: true },
        //                     { title: '资产4名称', key: '资产4 id', isLeaf: true },
        //                     { title: '资产5名称', key: '资产5 id', isLeaf: true }
        //                 ]
        //             },
        //             {
        //                 title: 'SaaS事业部',
        //                 key: 'SaaS事业部',
        //                 isLeaf: true
        //             },
        //             {
        //                 title: 'BSA',
        //                 key: 'BSA',
        //                 isLeaf: true
        //             },
        //             {
        //                 title: 'Websafe资产',
        //                 key: 'Websafe资产',
        //                 isLeaf: true
        //             }
        //         ]
        //     }
        // ];
    }

    toggel() {
        this.unvisible = !this.unvisible;
    }

    clear(ev) {
        this.value = null;
        ev.stopPropagation();
    }

    // 点击某个资产组
    nzClick(e) {
        this.keywords = '';
        this.childAssets.page_index = 1;
        const node = e.node;
        this.curGroupNodeKey = node.origin.key;
        const params = {
            assetType: 0,   // 表示“全部”资产
            viewId: this.viewValue.view_id,
            nodeId: node.origin.key,
            page: this.childAssets.page_index,
            size: this.childAssets.page_size
        };
        this.childAssets.p_name = node.origin.title;
        this.getChildAssets(params);
        this.value = {
            title: node.origin.title,
            value: String(node.origin.key),
            node_id: node.origin.title === '全部' ? 0 : node.origin.key,
            view_id: this.viewValue.view_id,
            view_name: this.viewValue.name,
            group: true
        };
    }
    setValue(data) {
        this.value = {
            title: data.asset_name,
            value: data.asset_uuid,
            asset_uuid: data.asset_uuid,
            asset_key: data.asset_key,
            view_id: this.viewValue.view_id,
            view_name: this.viewValue.name,
            group: false
        };
    }
    // 切换分页组件
    refreshPage(evt?: any) {
        if (evt) {
            this.childAssets.page_index = evt.pageIndex;
            this.childAssets.page_size = evt.pageSize;
        }
        const params = {
            assetType: 0,   // 表示“全部”资产
            viewId: this.viewValue.view_id,
            nodeId: this.curGroupNodeKey,
            page: this.childAssets.page_index,
            size: this.childAssets.page_size
        };
        if (this.keywords && this.keywords.length) {
            params['keywords'] = this.keywords;
        }
        this.getChildAssets(params);
    }

    getChildAssets(params) {
        this.childAssets.loading = true;
        this.getAssetListService(params).subscribe(
            res => {
                if (res.errCode === 0) {
                    this.childAssets.total = res.errMsg.totalSize;
                    this.childAssets.total_page = res.errMsg.totalPage;
                    this.childAssets.data = res.errMsg.data || [];
                } else {
                    this.childAssets.data = [];
                }
                this.childAssets.loading = false;
            },
            err => {
                this.childAssets.data = [];
                this.childAssets.loading = false;
            }
        );
    }

    // 异步加载得到子节点
    getChildren(event: NzFormatEmitEvent) {
        const node = event.node;
        if (event.eventName === 'expand') {
            // 展开下级节点
            if (node && node.getChildren().length === 0 && node.isExpanded) {
                const param = { viewid: this.viewValue.view_id, nodeid: node.origin.key };
                this.getAssetCommonService(param).subscribe(
                    res => {
                        if (res.errCode === 0) {
                            node.addChildren(this.formatNextNodeData(res.errMsg));
                        } else {
                        }
                    },
                    err => {
                    }
                );
            } else {
                return;
            }
        }
    }

    // 点击其他区域，关闭下拉框
    clickOutside(evt) {
        this.unvisible = true;
    }

    // 获取视图列表
    getViewListService() {
        const url = `/isoc/api/v1/threat_event/get_view_list`;
        return this.httpService.get(url, {});
    }

    // SP02修改 获取对应资产组的资产节点
    getAssetListService(params) {
        const url = '/asset/assetManage/list';
        return this.httpService.get(url, params);
    }
    // SP02修改 获取资产组节点
    getAssetCommonService(params) {
        const url = '/asset/assetCommon/attribute';
        return this.httpService.get(url, params);
    }
    // 切换视图
    switchViewList(event) {
        this.childAssets.data = undefined;
        this.childAssets.total = 0;
        this.viewValue = event;
        this.getAssets();
        this.value = { view_id: this.viewValue.view_id, value: '' };
    }

    switchInput(event) {
        if (event === '') {
            this.value = null;
        }
    }

    // 获取视图列表
    async getViewList(): Promise<any> {
        const data = await this.getViewListService().toPromise();
        this.viewList = data.data;
        this.viewValue = this.viewList[0];
    }

    // 获取第一级资产
    getAssets() {
        this.nodes = [];
        const params: any = {};

        // F01SP02，统一使用资产管理的接口
        params.viewid = this.viewValue.view_id;
        params.nodeid = this.viewValue.root_id;
        this.getAssetCommonService(params).subscribe(
            resp => {
                if (resp.errCode === 0) {
                const ret = [{
                    title: '全部',
                    key: this.viewValue.view_id,
                    expanded: true,
                    children: []
                }];
                ret[0].children = this.formatNextNodeData(resp.errMsg);
                this.nodes = [...ret];
                } else {
                }
            }, error => {
            }
        );
    }

    // 转换获取的视图数据(一级一级获取)
    // 转换下一级节点的数据
    formatNextNodeData(data: any) {
        const ret = [];
        data.forEach(
            (item: {
                name: string;
                id: number;
                parent_id: number;
                number: number;
                value: any;
            }) => {
                const tmp = {};
                tmp['title'] = item.name;
                tmp['key'] = item.id;
                tmp['pid'] = item.parent_id;
                tmp['value'] = item.value;
                tmp['isLeaf'] = item.number === 0;
                ret.push(tmp);
            }
        );
        return ret;
    }
}
