import { Component, OnInit, AfterViewInit, Input, ElementRef } from '@angular/core';
import { HttpService } from '../../../core';
import { NzModalService, NzMessageService } from 'ng-zorro-antd';

const $: any = (window as any).$;
/** 文件导出
 * exportOption：{
 *      fileNameUrl: `/as/attacker_export`,
        downloadUrl: `/as/download`,
        httpMethod: 'POST',
        dropdown: [{label: '导出为CSV', value: 'csv'}],
        params: {}
 * }
 */
@Component({
    selector: 'app-export-file',
    templateUrl: './export-file.component.html',
    styleUrls: ['./export-file.component.styl']
})
export class ExportFileComponent implements OnInit, AfterViewInit {
    // 是否正在创建文件
    creatFileIng = false;
    // 文件名称返回成功性
    resFileName = false;
    // 获取文件名称失败提示文字可见性
    fileNameError = false;
    // 失败信息提示
    errorMsg = '';
    // 文件名称
    fileName = '';
    // loading状态悬浮层元素
    $loadinLayer: any;
    $elem: any;
    @Input() exportOption: any;

    constructor(private elem: ElementRef, private httpService: HttpService,
        private modalService: NzModalService, private msgService:NzMessageService) {
        this.$elem = $(elem.nativeElement);
    }

    ngOnInit() {}
    ngAfterViewInit() {
        this.$loadinLayer = this.$elem.find('.loading-layer')[0];
    }
    exportData(e) {
        if (this.exportOption.tip) {
            this.modalService.info({
                nzTitle: `${this.exportOption.tip}`,
                nzContent: '',
                nzOnCancel: () => {},
                nzOnOk: () => this.export(e)
            });
        } else {
            this.export(e);
        }
    }
    export(e) {
        console.log(this.exportOption.params, 'this.exportOption.params');
        this.creatFileIng = true;
        this.resFileName = false;
        this.fileNameError = false;
        this.errorMsg = '';
        const url = this.exportOption.fileNameUrl;
        const params = this.exportOption.params;
        // params['export_type'] = e;
        this.httpService.post(url, {}, params).subscribe(
            (res) => {
                this.creatFileIng = false;
                if (res.filename !== undefined) {
                    if (res.filename) {
                        this.resFileName = true;
                        this.fileName = res.filename;
                    } else {
                        this.resFileName = false;
                        this.errorMsg = '当前数据为空！';
                        this.msgService.info(this.errorMsg);
                    }
                } else {
                    this.resFileName = true;
                    this.fileName = res;
                }
            },
            (error) => {
                this.creatFileIng = false;
                this.fileNameError = true;
                this.errorMsg = '获取文件名失败';
                this.msgService.info(this.errorMsg);
            }
        );
    }

    download() {
        this.$loadinLayer.style.visibility = 'visible';
        this.errorMsg = '';
        const url = this.exportOption.downloadUrl;
        const params = {file_path: this.fileName};
        $.fileDownload(url, {
            httpMethod: 'GET',
            data: params,
            successCallback: (url) => {
                this.$loadinLayer.style.visibility = 'hidden';
            },
            failCallback: (responseHtml, url) => {
                this.$loadinLayer.style.visibility = 'hidden';
                this.errorMsg = '下载文件失败';
                this.msgService.info(this.errorMsg);
            }
        });


    }

}
