import { Component, OnInit, OnChanges, Input, ElementRef, Output, EventEmitter, HostListener, SimpleChange } from '@angular/core';

interface SettingJson {
    labelField: string;
    valueField: string;
    searchMode?: boolean;
}
/**
 * 使用说明：
 * <app-multi-select (outbound)="outbound($event)" [setting]="dropdownSettings"
    [selectedItems]="selectedItems" [data]="data"></app-multi-select>
 * 参数说明
    setting: 设置对象的key值
        setting = {
            labelField: 'logname',
            valueField: 'tablename',
        }
    selectedItems：已选中的对象
    data: 所有备选对象
 */
@Component({
    selector: 'app-multi-select',
    host: {
        '(document:click)': 'collapse($event)',
    },
    templateUrl: './multi-select.component.html',
    styleUrls: ['./multi-select.component.styl']
})
export class MultiSelectComponent implements OnInit, OnChanges {
    @Input() selectedItems: Array<Object> = [];
    @Input() data: Array<Object> = [];
    @Input() setting: SettingJson = {
        labelField: '',
        valueField: '',
        searchMode: true
    };
    @Output() outbound = new EventEmitter();
    backUpdata: Array<Object> = [];
    allChecked = false;

    searchValue = '';
    isShown = false;                // 展示下拉框
    constructor(private _eref: ElementRef) { }

    ngOnInit() {
        // this.setting.labelField = 'logname';
        // this.setting.valueField = 'tablename';
        // this.selectedItems = [
        //     {logname: 'TAM FTP日志表V2', tablename: 'tam_ftplog'},
        //     {logname: 'TAM 邮件日志表V2', tablename: 'tam_maillog'},
        //     {logname: 'TAM 文件传输日志表V2', tablename: 'tam_filelog'}
        // ];
        // this.data = [
        //     {logname: 'TAM 告警表V2', tablename: 'tam_alertlog'},
        //     {logname: 'TAM 数据库日志表V2', tablename: 'tam_dblog'},
        //     {logname: 'TAM FTP日志表V2', tablename: 'tam_ftplog'},
        //     {logname: 'TAM 邮件日志表V2', tablename: 'tam_maillog'},
        //     {logname: 'TAM 文件传输日志表V2', tablename: 'tam_filelog'},
        //     {logname: 'TAM 社会账号日志表V2', tablename: 'tam_accountlog'},
        //     {logname: 'TAM DNS日志表V2', tablename: 'tam_dnslog'},
        //     {logname: 'TAM 会话日志表V2', tablename: 'tam_sessionlog'},
        //     {logname: 'TAM 接口流量日志表V2', tablename: 'tam_trafficlog'},
        //     {logname: 'TAM TELNET日志表V2', tablename: 'tam_telnetlog'},
        //     {logname: 'TAM 登录日志表V2', tablename: 'tam_loginlog'},
        //     {logname: 'TAM SSLTLS日志表V2', tablename: 'tam_ssltlslog'},
        //     {logname: 'TAM 认证日志表V2', tablename: 'tam_authlog'},
        //     {logname: 'TAM ICMP日志表V2', tablename: 'tam_icmplog'},
        //     {logname: 'TAM HTTP日志表V2', tablename: 'tam_httplog'}
        // ];
    }
    /**
     *  {labelField: '选项1', valueField: '1'} =>  {label: '选项1', value: '1', checked: false}
     */
    translateData(data, label, value) {
        this.data = data.map(item => {
            let checked = false;
            this.selectedItems.forEach(p => {
                if (item[value] === p[value]) {
                    checked = true;
                }
            });
            return { label: item[label], value: item[value], checked: checked };
        });
        this.allChecked = this.data.length === this.selectedItems.length;
    }
    translateSelectedData() {
        this.selectedItems = this.selectedItems.map(item => {
            return { label: item[this.setting.labelField], value: item[this.setting.valueField], checked: true };
        });
        this.translateData(this.data, 'label', 'value');
    }
    /**
     * 全选操作
     */
    updateAllChecked(): void {
        if (this.allChecked) {
            this.data.forEach(item => item['checked'] = true);
            this.selectedItems = [...this.data];
        } else {
            this.data.forEach(item => item['checked'] = false);
            this.selectedItems = [];
        }
        this.notifyParent();
    }
    /**
     * 单个选择操作
     */
    updateSingleChecked() {
        if (this.data.every(item => item['checked'] === false)) {
            this.allChecked = false;
        } else if (this.data.every(item => item['checked'] === true)) {
            this.allChecked = true;
        } else {
        }
        this.selectedItems = this.data.filter(item => item['checked']);
        this.notifyParent();
    }
    /**
     * 删除已选择的项目
     */
    deleteSelect(item, i) {
        const index = this.findIndex(this.data, item);
        this.data[index]['checked'] = false;
        this.selectedItems.splice(i, 1);
        this.notifyParent();
    }
    search() {
        const data = this.backUpdata.filter(item =>
            item[this.setting.labelField].indexOf(this.searchValue === null ? '' : this.searchValue) !== -1
        );
        this.data = data.map(item => {
            let checked = false;
            this.selectedItems.forEach(p => {
                if (item[this.setting.valueField] === p['value']) {
                    checked = true;
                }
            });
            return { label: item[this.setting.labelField], value: item[this.setting.valueField], checked: checked };
        });
        if (data.length <= this.selectedItems.length && data.length !== 0) {
            this.allChecked = true;
        } else {
            this.allChecked = false;
        }
    }
    /**
     * 对象数组索引
     * @param 数组
     * @param 对象
     */
    findIndex(l, o) {
        const objStr = JSON.stringify(o);
        return l.reduce((index, ele, i) => {
            if (JSON.stringify(ele) === objStr) {
                return i;
            } else {
                return index;
            }
        }, -1);
    }
    /**
     * 打开下拉框
     */
    showDropDown() {
        this.isShown = !this.isShown;
    }
    collapse(event) {
        // Checks to see if click is inside element; if not, collapse element
        if (!(this._eref.nativeElement.contains(event.target))) {
            this.isShown = false;
        }
    }
    stopBubble(evt) {
        evt.stopPropagation();
    }
    /**
     * 向父组件传递事件，注意，此处保存用户已选择的对象
     */
    notifyParent() {
        const indexArr = [];
        this.selectedItems.forEach(item => {
            indexArr.push({ [this.setting.labelField]: item['label'], [this.setting.valueField]: item['value'] });
        });
        this.outbound.emit(indexArr);
        this.isShown = true;
    }
    ngOnChanges(changes: { [propKey: string]: SimpleChange }) {
        const data = changes['data'];
        const selectedItems = changes['selectedItems'];
        if (data && data.currentValue) {
            this.backUpdata = [...this.data];
            this.translateData(this.data, this.setting.labelField, this.setting.valueField);
        }
        if (selectedItems && selectedItems.currentValue && selectedItems.currentValue.length > 0) {
            if (this.data) {
                this.translateSelectedData();
            }
            if (selectedItems.currentValue.length < selectedItems.previousValue.length) {
                // 处理删除查询条件时，触发查询动作
                this.outbound.emit(selectedItems.currentValue);
            }
        } else {
            if (selectedItems && !selectedItems.firstChange && selectedItems.currentValue.length === 0 ) {
                // 处理删除查询条件时，触发查询动作
                this.outbound.emit(selectedItems.currentValue);
            }
            this.selectedItems = [];
            this.allChecked = false;
            if (this.data) {
                this.data = this.data.map(item => {
                    return { label: item['label'], value: item['value'], checked: false };
                });
            } else {
                this.data = [];
            }
        }
    }

}
