import { Component, Input, Output, ElementRef, OnInit, EventEmitter, AfterViewInit } from '@angular/core';
import { GeoConstantService } from '../../../core';
const $: any = (window as any).$;
/**地域组件 使用说明
 *两种场景：
 * 1.国家省份城市  <app-region [(outputRegion)]=outputRegion ></app-region>
 * 2.没有城市<app-region [(outputRegion)]=outputRegion [theme]=''noCity''></app-region>
 * 配置参数 可设置默认国家省份城市也可以不设置
 * outputRegion:any = {
        outputCountry: '',
        outputProvince: '',
        outputCity: ''
    };
 * 返回值为outputRegion={
 *      outputCountry: '中国',
        outputProvince: '重庆',
        outputCity: ''  // 主题为noCity时为空
    }
 */
@Component({
    selector: 'app-region',
    templateUrl: './region.component.html',
    styleUrls: ['./region.component.styl']
})
export class RegionComponent implements OnInit, AfterViewInit {
    // 先声明变量，在构造函数中初始化
    $elem: any;

    outputRegionValue: any;
    @Input() theme = '';
    @Output() outputRegionChange = new EventEmitter();

    @Input()
    get outputRegion() {
        return this.outputRegionValue;
    }
    set outputRegion(value) {
        this.outputRegionValue = value;
        if (this.outputRegionValue) {
            this.outputCountryText = this.outputRegionValue.outputCountry;
        }
        this.outputRegionChange.emit(this.outputRegionValue);
    }

    outputCountryText = '全部';

    $label: any;
    $back: any;
    $cityBack: any;
    $title: any;
    $tabIndex: any;
    $list: any;
    $listProvince: any;
    $listCity: any;
    $tab: any;

    constructor(elem: ElementRef, private geoConstantService: GeoConstantService) {
        this.$elem = $(elem.nativeElement);
    }

    ngOnInit() {
        // this.outputRegion = this.outputRegion || {};
        this.outputRegionValue = this.outputRegion || {
            outputCountry: '',
            outputProvince: '',
            outputCity: ''
        };
    }

    showLabel() {
        this.$list.show();
        this.$title.html('选择国家：');
        this.$tab.show();
        this.$listProvince.hide();
        this.$listCity.hide();
        this.$back.hide();
        this.$cityBack.hide();
        this.$tabIndex.first().trigger('mouseover');
    }

    showProvinceLabel() {
        this.$listProvince.show();
        this.$title.html('选择省份');
        this.$back.show();
        this.$cityBack.hide();
        this.$listCity.hide();
        this.$list.hide();
        this.$tab.hide();
    }

    showCityLabel() {
        this.$listCity.show();
        this.$title.html('选择城市');
        this.$back.hide();
        this.$cityBack.show();
        this.$list.hide();
        this.$tab.hide();
    }

    hideLabel() {
        this.$label.hide();
    }

    getCountryAndProvince() {
        const provinces = this.geoConstantService.geoProvince;
        const cities = this.geoConstantService.cityAlias;
        const countries = this.geoConstantService.countries;

        const options = ['country', 'province']; // 国家和省份的面板
        const grade = options[0];

        const $input = this.$elem.find('.region-input');

        const that = this;
        // 初始化面板的html
        // 将国家分为不同区段：热门，a-b，c-i，j-m，n-v,w-z
        const sector = [0, 5, 48, 87, 140, 186];
        // 生成国家选择的面板
        sector.forEach(function(value, index) {
            const min = value;
            const max = sector[index + 1] || countries.length;
            const countryArr = [];
            for (let i = min; i < max; i++) {
                countryArr.push('<li class="region-item"><a href="javascript:;" data-key="' +
                countries[i].value + '">' + countries[i].value + '</a></li>');
            }
            that.$list.eq(index).html(countryArr.join(''));
        });

        const provinceArr = [];
        // 生成省份选择的面板
        provinces.forEach(function(v, i) {
            provinceArr.push('<li class="region-item"><a href="javascript:;" data-key="' + v.key + '">' + v.value + '</a></li>');
        });
        that.$listProvince.first().html(provinceArr.join(''));

        // 鼠标移动到tab上，打开关联的页签
        // tab高亮背景,切换tab
        that.$tabIndex.on('mouseover', function(e) { // click
            const $this = $(this);
            that.$tabIndex.not($this).removeClass('active');
            $this.addClass('active');
            const index = parseInt($this.data('index'));
            that.$list.not(that.$list.eq(index)).hide();
            that.$list.eq(index).show();
        });

        $input.on('click', function() {
            that.$label.fadeIn('fast');
            if (that.outputRegion.outputCity) {
                that.showCityLabel();
            } else if (that.outputRegion.outputProvince) {
                that.showProvinceLabel();
            } else {
                that.showLabel();
            }
        });

        // 国家选择
        that.$list.on('click', function(e) {
            e.stopPropagation();
            const $target = $(e.target);
            if (e.target.tagName.toLowerCase() === 'a') {
                that.outputRegion.outputCountry = $target.data('key');
                that.outputRegion.outputProvince = '';
                that.outputRegion.outputCity = '';
                that.outputCountryText = that.outputRegion.outputCountry ? that.outputRegion.outputCountry : '全部';
                if (that.outputRegion.outputCountry.indexOf('中国') >= 0) {
                    that.showProvinceLabel();
                    that.outputRegionChange.emit(that.outputRegion);
                    return;
                }
                that.hideLabel();
            }
            that.outputRegion.outputCountry = (that.outputRegion.outputCountry === '全部') ? '' : that.outputRegion.outputCountry;
            that.outputRegionChange.emit(that.outputRegion);
        });

        // 省份选择
        that.$listProvince.on('click', function(e) {
            e.stopPropagation();
            const $target = $(e.target);
            if (e.target.tagName.toLowerCase() === 'a') {
                that.outputRegion.outputProvince = $target.data('key');
                that.outputRegion.outputCity = '';
                const cityArr = [];
                that.$listProvince.hide();
                // 生成省份选择的面板
                for (const city in cities) {
                    if (city === that.outputRegion.outputProvince ) {
                        for (let childCity in cities[city]) {
                            cityArr.push('<li class="region-item"><a href="javascript:;" data-key="' + childCity + '">' + childCity + '</a></li>');
                        }
                    } else {

                    }
                }
                that.$listCity.first().html(cityArr.join(''));
                if (that.theme === 'noCity') {
                    that.hideLabel();
                } else {
                    that.showCityLabel();
                }
            }
            that.outputCountryText = that.outputRegion.outputCountry ;
            that.outputRegion.outputProvince = that.outputRegion.outputProvince;
            that.outputRegionChange.emit(that.outputRegion);
        });

        // 城市选择
        that.$listCity.on('click', function(e) {
            e.stopPropagation();
            const $target = $(e.target);
            if (e.target.tagName.toLowerCase() === 'a') {
                that.outputRegion.outputCity = $target.data('key');
                that.hideLabel();
            }
            that.outputRegionChange.emit(that.outputRegion);
        });

        that.$back.on('click', function() {
            that.showLabel();
        });

        that.$cityBack.on('click', function() {
            that.showProvinceLabel();
        });
    }

    // 点击其他区域，关闭下拉框
    clickOutside(evt) {
        this.hideLabel();
    }

    ngAfterViewInit() {
        if (this.outputRegion.outputCountry) {
            if (this.outputRegion.outputCountry.length === 0) {
                this.outputCountryText = '全部';
            } else {
                this.outputCountryText = this.outputRegion.outputCountry;
            }
        }

        this.$label = this.$elem.find('.region-label');
        this.$back = this.$elem.find('.region-back');
        this.$cityBack = this.$elem.find('.city-back');
        this.$title = this.$elem.find('.region-title');
        this.$tab = this.$label.find('.region-tab');
        this.$tabIndex = this.$tab.children('li');
        this.$list = this.$label.find('.region-list').children('ul');
        this.$listProvince = this.$elem.find('.region-list-second').children('ul');
        this.$listCity = this.$elem.find('.region-list-third').children('ul');

        this.getCountryAndProvince();
    }
}
