import { Component, OnInit, Input, Output, EventEmitter, SimpleChange, OnChanges } from '@angular/core';
import { TimeRangeService } from '../../../core';
/**
 * <app-time-range [timeIndex]="timeIndex" (outbound)="outbound($event)"></app-time-range>
 * 参数说明：
 *      timeIndex:默认展示哪个时间区间 ('last_30_days' / 'last_24_hours' / 'last_7_days' / 'last_1_hour')
 *      outbound:广播事件，参数为 { startTime: null, endTime: null } 时间形式为标准时间
 */
@Component({
    selector: 'app-time-range',
    templateUrl: './time-range.component.html',
    styleUrls: ['./time-range.component.styl']
})
export class TimeRangeComponent implements OnInit, OnChanges {
    @Input() timeIndex = '';
    @Output() outbound = new EventEmitter();
    timeRange: any;

    constructor(private timeRangeService: TimeRangeService) {
        // 获取时间区间对应的开始时间和结束时间
        this.timeRange = this.timeRangeService.getTimeRange();
    }

    ngOnInit() {
    }

    indexChange(evt) {
        let date = { startTime: null, endTime: null };

        this.timeRange = this.timeRangeService.getTimeRange();
        switch (evt) {
            case 'last_30_days':
                date = this.timeRange.last_30_days;
                break;
            case 'last_24_hours':
                date = this.timeRange.last_24_hours;
                break;
            case 'last_7_days':
                date = this.timeRange.last_7_days;
                break;
            case 'last_1_hour':
                date = this.timeRange.last_1_hour;
                break;
            case 'today':
                date = this.timeRange.today;
                break;
            default:
                break;

        }
        this.outbound.emit({
            date: {...date},
            timeIndex: this.timeIndex
        });
    }

    ngOnChanges(changes: { [propKey: string]: SimpleChange }) {
        const timeIndex = changes['timeIndex'];
        if (timeIndex.currentValue) {
            this.indexChange(timeIndex.currentValue);
        }
    }

}
