import {Directive, ElementRef, Output, EventEmitter, HostListener} from '@angular/core';
/**
 * 捕获点击事件，点击绑定元素外
 */
@Directive({
    selector: '[appClickOutside]'
})
export class ClickOutsideDirective {
    @Output()
    public appClickOutside = new EventEmitter<MouseEvent>();

    constructor(private _elementRef: ElementRef) {
    }

    @HostListener('document:click', ['$event', '$event.target'])
    public onClick(event: MouseEvent, targetElement: HTMLElement): void {
        if (!targetElement) {
            return;
        }

        const clickedInside = this._elementRef.nativeElement.contains(targetElement);
        if (!clickedInside) {
            this.appClickOutside.emit(event);
        }
    }

}
