import { Component, Input, OnInit, OnChanges, SimpleChanges } from '@angular/core';
import { NzMessageService } from 'ng-zorro-antd';
import { NoticeService } from '../../../service/https/notice.service';

@Component({
  selector: 'app-path',
  templateUrl: './path.component.html',
  styleUrls: ['./path.component.styl']
})
export class PathComponent implements OnInit, OnChanges {
  @Input() detail_data: any;
  data;
  viewType = 0;
  whiteListParam = {};
  greyListParam = {};
  rules;
  queryLogUrl = "/WebApi/isoc/static/base/#/route/threat-state/log/action?"
  // /WebApi/isoc/static/base/#/route/threat-state/log/action?startTime=1717396269&endTime=1717403469&sip=zhang3
  startTime;
  endTime;
  constructor(
    private noticeService: NoticeService,
    public message: NzMessageService,

  ) {}

  ngOnInit() {
    // const jsonStr = '{"type":3,"http://190.89.233.2:8909/getpublicconfig":[{"req_ip":"192.156.3.12","interface_addr":"http://190.89.233.2:8909/getpublicconfig","req_jobnum":43327,"req_frequency":43,"req_account":"liuhr"},{"req_ip":"192.156.3.12","interface_addr":"http://190.89.233.2:8909/getpublicconfig","req_jobnum":43328,"req_frequency":44,"req_account":"sunxq01"},{"req_ip":"192.156.3.18","interface_addr":"http://190.89.233.2:8909/getpublicconfig","req_jobnum":65341,"req_frequency":45,"req_account":"shicl"},{"req_ip":"192.106.3.33","interface_addr":"http://190.89.233.2:8909/getpublicconfig","req_jobnum":65342,"req_frequency":46,"req_account":"gongxs"},{"req_ip":"192.106.3.34","interface_addr":"http://190.89.233.2:8909/getpublicconfig","req_jobnum":65343,"req_frequency":47,"req_account":"sunzs"}]}'
    // if (this.detail_data == null) {
    //   this.detail_data = JSON.parse(jsonStr);
    // }
    this.parseData();
    if (this.rules === undefined) {
      this.noticeService.getDefaultRule().subscribe(
        resp => {
          if (resp.code === 200) {
            this.rules = resp.data;
          } else {
            this.message.error(resp.msg);
          }
        },
        error => {
          this.message.error('服务器错误');
        }
      );
    }
  }

  ngOnChanges(changes: SimpleChanges) {
    if ('detail_data' in changes) {
      this.parseData();
      // 在这里处理接收到的数据
    }
  }

  parseData() {
    for (const dataKey in this.detail_data) {
      if (this.detail_data.hasOwnProperty(dataKey)) {

        switch (dataKey) {
          case 'type':
            this.viewType = this.detail_data[dataKey];
            break;
          case 'startTime':
            this.startTime = this.detail_data[dataKey];
            break;
          case 'endTime':
            this.endTime = this.detail_data[dataKey];
            break;
          default:
            this.data = this.detail_data[dataKey];
            this.data.forEach(item => {
              item['is_in_white_list'] = 0; 
              item['is_in_grey_list'] = 0; 
            });
        }
      }
    }
  }

  clickWihteList(data) {
    let index = -1;
    // this.message.success('添加白名单成功!');
    // this.data[index]['is_in_white_list'] = 1;
    this.whiteListParam['range'] = ["ueba"];
    this.whiteListParam['des'] = "";
    this.whiteListParam['is_enable'] = 1;
    switch(this.viewType) {
      case 1:
        this.whiteListParam['fields'] = ["sip"];
        this.whiteListParam['name'] = data.req_ip + '-' + this.getCurrentTime();
        this.whiteListParam['content'] = {"sip": data.req_ip};
        this.whiteListParam['alert_rule_id'] = this.rules["white_list"]["ip"];
        index = this.data.findIndex(item => item.req_ip === data.req_ip);
        break;
      case 2:
        this.whiteListParam['fields'] = ["url"];
        this.whiteListParam['name'] = data.interface_addr + '-' + this.getCurrentTime();
        this.whiteListParam['content'] = {"url": data.interface_addr};
        this.whiteListParam['alert_rule_id'] = this.rules["white_list"]["interface"];
        index = this.data.findIndex(item => item.interface_addr === data.interface_addr);
        break;
      case 3:
        break;
      case 4:
        break;
    }
    this.noticeService.addWhitelist(this.whiteListParam).subscribe(
      resp => {
        if (resp.status === 200) {
          this.message.success('添加白名单成功!');
          this.data[index]['is_in_white_list'] = 1;
        } else {
          this.message.error(resp.msg);
        }
      },
      error => {
        this.message.error('服务器错误');
      }
    );
  }

  clickGreyList(data) {
    let index = -1;
    // this.message.success('添加灰名单成功!');
    // this.data[index]['is_in_grey_list'] = 1;
    this.greyListParam['des'] = "";
    this.greyListParam['is_enable'] = 1;
    switch(this.viewType) {
      case 1:
        this.greyListParam['fields'] = ["sip"];
        this.greyListParam['name'] = data.req_ip + '-' + this.getCurrentTime();
        this.greyListParam['content'] = {"sip": data.req_ip};
        this.greyListParam['alert_rule_id'] = this.rules["grey_list"]["ip"];
        index = this.data.findIndex(item => item.req_ip === data.req_ip);
        break;
      case 2:
        this.greyListParam['fields'] = ["url"];
        this.greyListParam['name'] = data.interface_addr + '-' + this.getCurrentTime();
        this.greyListParam['content'] = {"url": data.interface_addr};
        this.greyListParam['alert_rule_id'] = this.rules["grey_list"]["interface"];
        index = this.data.findIndex(item => item.interface_addr === data.interface_addr);
        break;
      case 3:
        break;
      case 4:
        break;
    }
    this.greyListParam["type"]=0;
    this.noticeService.addGreyList(this.greyListParam).subscribe(
      resp => {
        if (resp.status === 200) {
          this.message.success('添加灰名单成功!');
          this.data[index]['is_in_grey_list'] = 1;
        } else {
          this.message.error(resp.msg);
        }
      },
      error => {
        this.message.error('服务器错误');
      }
    );
  }

  clickFrequency(data) {
    if(this.detail_data!=undefined){
      var params = "startTime="+this.detail_data.startTime+"&endTime="+this.detail_data.endTime;
      switch(this.detail_data.type) {
        case 1:
          params += "&sip="+data.req_ip;
          break;
        case 2:
          params += "&sip="+data.req_account;
          break;
        case 3:
          params += "&sip="+data.interface_addr;
          break;
        case 4:
          params += "&sip="+data.menu_name;
          break;
      }

      window.open(this.queryLogUrl+params, '_blank');
    }
  }

  // 在组件类中
  getCurrentTime(): string {
    const now = new Date();
    const year = now.getFullYear();
    const month = String(now.getMonth() + 1).padStart(2, '0'); // 月份是从0开始的
    const day = String(now.getDate()).padStart(2, '0');
    const hours = String(now.getHours()).padStart(2, '0');
    const minutes = String(now.getMinutes()).padStart(2, '0');
    const seconds = String(now.getSeconds()).padStart(2, '0');
    
    return `${year}/${month}/${day} ${hours}:${minutes}:${seconds}`;
  }

}
