import {Pipe, PipeTransform} from '@angular/core';
import { forEach } from '@angular/router/src/utils/collection';

@Pipe({
  name: 'eventStatus'
})
export class EventStatusPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const status = {
      0: '新建',
      1: '研判中',
      2: '处置中',
      3: '已处理',
      4: '忽略',
      5: '误报',
    };
    return status[value] || value;
  }
}

@Pipe({
  name: 'eventClass'
})
export class EventClassPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const type = {
      1: '威胁事件',
      2: '失陷资产'
    };
    return type[value] || value;
  }
}

@Pipe({
  name: 'eventLevel'
})
export class EventLevelPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const level = {
      5: '特别重大',
      4: '重大',
      3: '较大',
      2: '一般',
      1: '轻微'
    };
    return level[value] || value;
  }
}

@Pipe({
  name: 'priorityTry'
})
export class PriorityTryPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const priority = {
      1: '极高',
      2: '高',
      3: '中',
      4: '低'
    };
    return priority[value] || value;
  }
}

@Pipe({
  name: 'attResult'
})
export class AttResultPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const result = {
      '0': '未知',
      '-1': '失败',
      '1': '成功'
    };
    return result[value] || value;
  }
}

@Pipe({
  name: 'attDir'
})
export class AttDirPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const result = {
      1: '未知',
      2: '内部攻击',
      3: '外部攻击'
    };
    return result[value] || value;
  }
}

@Pipe({
  name: 'eventObject'
})
export class EventObjectPipe implements PipeTransform {
  transform(objJson: any, args?: any): any {
    let objStr = '';
    objJson.map(opt => {
      objStr += ('; ' + opt.name);
    });
    const result = objStr.slice(1);
    return result;
  }
}

@Pipe({
  name: 'nameTrans'
})
export class NameTransPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const str = {
      'fuzzy': '（名称/对象）关键字',
      'eventName': '事件名称',
      'eventIp': '运维对象',
      'sourceIp': '源 IP',
      'sport': '源端口',
      'dscIp': '目的 IP',
      'dport': '目的端口',
      'selectType': '类型',
      'selectClass': '分类',
      'selectLevel': '等级',
      'eventId': '事件 ID',
      'attResult': '攻击结果',
      'eventCount': '次数',
      'attDirection': '攻击方向',
      'eventSource': '来源',
      'priority': '优先级',
      'selectStatus': '状态',
      'suggest': '处置建议',
      'executor': '研判人',
      'assetName': '资产名称',
      'assetLevel': '脆弱性级别',
      'intention': '攻击意图',
      'disposeModes': '处置方式',
      'related_ticket': '关联工单',
      'related_case_name': '案例名称',
      'disposeResults': '处置结果',
      'event_rule_id': '规则 ID',
      'kill_chain_stage': '攻击链',
      'codeId': '响应码',
      'operationScene': '运营场景',
      'asset': '资产组',
      'tiField': '威胁情报IOC',
    };
    return str[value] || value;
  }
}

@Pipe({
  name: 'statusToClass'
})
export class StatusToClassPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const status = {
      0: 'new',
      1: 'judging',
      2: 'disposing',
      3: 'fixed',
      4: 'ignore',
      5: 'misreport'
    };
    return status[value] || value;
  }
}

@Pipe({
  name: 'levelToClass'
})
export class LevelToClassPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const level = {
      5: 'deadly',
      4: 'severe',
      3: 'middle',
      2: 'normal',
      1: 'slight'
    };
    return level[value] || value;
  }
}

@Pipe({
  name: 'priorityToClass'
})
export class PriorityToClassPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const priority = {
      1: 'high',
      2: 'higher',
      3: 'mid',
      4: 'low'
    };
    return priority[value] || value;
  }
}

@Pipe({
  name: 'resultToClass'
})
export class ResultToClassPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const result = {
      0: 'unknow',
      '-1': 'fail',
      1: 'success'
    };
    return result[value] || value;
  }
}

@Pipe({
  name: 'statusToColor'
})
export class StatusToColorPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const status = {
      0: '#FF7088',
      1: '#FDCD2F',
      2: '#FD8701',
      3: '#00CAC7',
      4: '#67CBFF',
      5: '#0299FF'
    };
    return status[value] || value;
  }
}

@Pipe({
  name: 'attackToColor'
})
export class AttackToColorPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const result = {
      '0': '#FF9927',
      '-1': '#65CC33',
      '1': '#FE3255'
    };
    return result[value] || value;
  }
}

@Pipe({
  name: 'executeTime'
})
export class ExecuteTimePipe implements PipeTransform {
  transform(seconds: any): any {
    if (!seconds) {
      return '00 天 00 分 00 秒';
    } else {
      const day = Math.floor(seconds / (60 * 60 * 24));
      const hours = Math.floor(seconds % (60 * 60 * 24) / (60 * 60));
      const minutes = Math.floor(seconds % (60 * 60) / 60);
      const second = Math.floor(seconds % 60);

      return day + ' 天 ' + hours + ' 小时 ' + minutes + ' 分钟 ' + second + ' 秒 ';
    }
  }
}

@Pipe({
  name: 'descFormat'
})
export class DescFormatPipe implements PipeTransform {

  transform(value: any, args?: any): any {
    if (!value || value === '') {
      return '无';
    }
    const valueStr1 = value.split('\\r\\n').join('\n');
    const valueStr = valueStr1.split('\\n').join('\n');
    return valueStr;
  }

}

@Pipe({
  name: 'riskLevel'
})
export class RiskLevelPipe implements PipeTransform {
  transform(value: any, ...args: any[]): any {
    if (value === null || typeof value === 'undefined' || value === '') {
      return 'N/A';
    }
    if (value >= 0 && value < 1) {
      return '非常安全';
    } else if (value >= 1 && value < 5) {
      return '比较安全';
    } else if (value >= 5 && value < 8) {
      return '比较危险';
    } else if (value >= 8 && value <= 10) {
      return '非常危险';
    }

  }
}

@Pipe({
  name: 'assetCategory'
})
export class AssetCategoryPipe implements PipeTransform {
  transform(value: any, ...args: any[]): any {
    const assetCategoryMap = {
      7: '主机',
      4: '网段',
      3: '网站'
    };
    const assetCategoryList = Object.keys(assetCategoryMap).map(i => parseInt(i, 10));
    if (assetCategoryList.indexOf(value) !== -1) {
      return assetCategoryMap[value];
    } else {
      return '未知';
    }
  }
}


@Pipe({
  name: 'vulnProduct'
})
export class VulnProductPipe implements PipeTransform {
  transform(value: any, ...args: any[]): any {
    const productMap = {
      1: '绿盟',
      2: 'websafe',
      4: '启明',
      8: '渗透',
      16: 'Nessus'
    };
    const productIdList = Object.keys(productMap).map(i => parseInt(i, 10));
    if (productIdList.indexOf(value) !== -1) {
      return productMap[value];
    } else {
      return '未知';
    }
  }
}

@Pipe({
  name: 'sliceName'
})
export class SliceNamePipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const isLongTag = value.length > 32;
    return isLongTag ? `${value.slice(0, 32)}...` : value;
  }
}

@Pipe({
  name: 'disposeResult'
})
export class DisposeResultPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const disposeResults = {
      4: '未处置',
      3: '处置中',
      0: '成功',
      1: '失败',
      2: '部分成功'
    };
    value = disposeResults[value] || '-';
    return value;
  }
}

@Pipe({
  name: 'priority'
})
export class PriorityPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const priority = {
      1: '极高',
      2: '高',
      3: '中',
      4: '低'
    };
    return priority[value] || value;
  }
}
