import { Pipe, PipeTransform } from '@angular/core';
import { attackChainColor, autoRefreshFrequency } from '../service/constant/senior-constant.service';

@Pipe({
  name: 'seniroEventObject'
})
export class SeniorEventObjectPipe implements PipeTransform {
  transform(objJson: any, args?: any): any {
    let objStr = '';
    objJson.map(opt => {
      objStr += ('; ' + opt.asset_name);
    });
    const result = objStr.slice(1);
    return result;
  }
}

@Pipe({
  name: 'seniorLevelToClass'
})
export class SeniorLevelToClassPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const level = {
      '特别重大': 'deadly',
      '重大': 'severe',
      '较大': 'middle',
      '一般': 'normal',
      '轻微': 'slight',
      '未知': 'unknowalert'
    };
    return level[value] || value;
  }
}

@Pipe({
  name: 'seniorPriorityToClass'
})
export class SeniorPriorityToClassPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const priority = {
      '极高': 'high',
      '高': 'higher',
      '中': 'mid',
      '低': 'low',
      '极低': 'lower'
    };
    return priority[value] || 'default';
  }
}

@Pipe({
  name: 'seniorResultToClass'
})
export class SeniorResultToClassPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const result = {
      '未知': 'unknow',
      '失败': 'fail',
      '成功': 'success'
    };
    return result[value] || value;
  }
}

@Pipe({
  name: 'attackChain'
})
export class AttackChainPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    if (value) {
      return attackChainColor[value][args] || value;
    }
    return '';
  }
}

@Pipe({
  name: 'decodeUri'
})
export class DecodeUriPipe implements PipeTransform {

  transform(value: any, args?: any): any {
    try {
      return decodeURIComponent(decodeURIComponent(value.replace(/%/g, '%25')));
    } catch (e) {
      return value;
    }
  }

}

@Pipe({
  name: 'nullShow'
})
export class NullShowPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const level = {
      '': '无'
    };
    return level[value] || value;
  }
}

@Pipe({
  name: 'alertlevelToClass'
})
export class AlertLevelToClassPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const level = {
      '特别重大': 'deadly',
      '重大': 'severe',
      '较大': 'middle',
      '一般': 'normal',
      '轻微': 'slight',
      '未知': 'unknowalert',
    };
    return level[value] || value;
  }
}

@Pipe({
  name: 'alertlevel'
})
export class AlertLevelPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const level = {
      '特别重大': 'Ⅰ级 特别重大',
      '重大': 'Ⅱ级 严重',
      '较大': 'Ⅲ级 较大',
      '一般': 'Ⅳ级 一般',
      '轻微': 'Ⅴ级 轻微'
    };
    return level[value] || value;
  }
}

@Pipe({
  name: 'stage'
})
export class StagePipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const status = {
      0: '--',
      1: '侦察',
      2: '工具制作',
      3: '投送',
      4: '攻击渗透',
      5: '安装工具',
      6: '命令控制',
      7: '恶意活动'
    };
    return status[value] || value;
  }
}

@Pipe({
  name: 'eventType'
})
export class EventTypePipe implements PipeTransform {
  transform(value: any, args?: any): any {
    if (!value) {
      return '威胁类';
    } else {
      const status = {
        1: '威胁类',
        2: '失陷资产类'
      };
      return status[value] || value;
    }
  }
}

// @Pipe({
//   name: 'eventSource'
// })
// export class EventSourcePipe implements PipeTransform {
//   transform(value: any, args?: any): any {
//       const status = {
//         'CEP': '平台-攻击识别引擎',
//         'SIMPLE': '设备-探针侧告警',
//         'COMPASSET': '平台-威胁推理引擎'
//       };
//       return status[value] || value;
//     }
// }

@Pipe({
  name: 'time'
})
export class TimePipe implements PipeTransform {
  transform(time: any): any {
    if (!time) {
      return '-';
    } else {
      const now = new Date(time);
      const year = now.getFullYear();
      const month = now.getMonth() + 1;
      const date = now.getDate();
      const hour = now.getHours();
      const minute = now.getMinutes();
      const second = now.getSeconds();
      return year + "-" + month + "-" + date + "  " + hour + ":" + minute + ":" + second;
    }
  }
}

@Pipe({
  name: 'resultNewToClass'
})
export class ResultnewToClassPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const result = {
      "未知": 'unknow',
      "失败": 'fail',
      "成功": 'success'
    };
    return result[value] || value;
  }
}
@Pipe({
  name: 'autoRefreshIndex'
})
export class AutoRefreshIndexPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const result = {
      'last_1_hour': '最近1小时',
      'today': '今天',
      'last_7_days': '最近7天'
    };
    return result[value] || value;
  }
}
@Pipe({
  name: 'autoRefreshFrequency'
})
export class AutoRefreshFrequencyPipe implements PipeTransform {
  transform(value: any, args?: any): any {
    const result = autoRefreshFrequency.filter(item => item.value === value);
    return result[0].label || value;
  }
}
